import PDFJSAnnotate from '../PDFJSAnnotate';
import { appendChild } from '../render/appendChild';
import {
  BORDER_COLOR,
  findSVGAtPoint,
  getMetadata,
  convertToSvgPoint
} from './utils';

let _enabled = false;
let input;
let _textSize;
let _textColor;

/**
 * Handle document.mouseup event
 *
 * @param {Event} e The DOM event to handle
 */
function handleDocumentMouseup(e) {
  if (input || !findSVGAtPoint(e.clientX, e.clientY)) {
    return;
  }
  if (!e.target.classList.contains('annotationLayer')) {
    // console.log('annot', e);
    input = window.document.createElement('textarea');
    input.setAttribute('id', 'pdf-annotate-text-input');
    input.innerText = e.target.textContent;
    input.innerHTML = e.target.textContent;
    input.style.width = `200px`;
    input.style.height = `100px`;
    input.style.border = `3px solid ${BORDER_COLOR}`;
    input.style.borderRadius = '3px';
    input.style.position = 'absolute';
    input.style.top = `${e.clientY}px`;
    input.style.left = `${e.clientX}px`;
    input.style.fontSize = `${_textSize}px`;
    input.style.zIndex = '41';
    input.addEventListener('blur', handleInputBlur);
    input.addEventListener('keyup', handleInputKeyup);
    // console.log('input', input)
    window.document.body.appendChild(input);
    input.focus();
    e.target.remove();
    return;
  }
  input = window.document.createElement('textarea');
  input.setAttribute('id', 'pdf-annotate-text-input');
  input.setAttribute('placeholder', 'Placez votre texte ici');
  input.style.width = `200px`;
  input.style.height = `100px`;
  input.style.border = `3px solid ${BORDER_COLOR}`;
  input.style.borderRadius = '3px';
  input.style.position = 'absolute';
  input.style.top = `${e.clientY}px`;
  input.style.left = `${e.clientX}px`;
  input.style.fontSize = `${_textSize}px`;
  input.style.zIndex = '41';
  input.addEventListener('blur', handleInputBlur);
  input.addEventListener('keyup', handleInputKeyup);
  // console.log('input', input.style)
  const parent = window.document.getElementById('pageContainer1')
  parent.appendChild(input);
  input.focus();
}

/**
 * Handle input.blur event
 */
function handleInputBlur() {
  saveText();
}

/**
 * Handle input.keyup event
 *
 * @param {Event} e The DOM event to handle
 */
function handleInputKeyup(e) {
  if (e.keyCode === 27) {
    closeInput();
  }
  // else if (e.keyCode === 13) {
  //   saveText();
  // }
}

/**
 * Save a text annotation from input
 */
function saveText() {
  let value = (input.value) ? input.value.replace(/ +$/, '') : '';
  if (value.length > 0) {
    let clientX = parseInt(input.style.left, 10);
    let clientY = parseInt(input.style.top, 10);
    let svg = findSVGAtPoint(clientX, clientY);
    if (!svg) {
      return;
    }
    let height = _textSize;
    let { documentId, pageNumber, viewport } = getMetadata(svg);
    let scale = 1 / viewport.scale;
    let rect = svg.getBoundingClientRect();
    let pt = convertToSvgPoint([
      clientX - rect.left,
      clientY - rect.top + height], svg, viewport);
    const temp = document.querySelector('.admin-color').childNodes[0]
    _textColor = temp.getAttribute('data-color')
    let annotation = {
      type: 'textbox',
      size: _textSize * scale,
      color: _textColor,
      content: value,
      x: pt[0],
      y: pt[1],
      rotation: -viewport.rotation
    };

    PDFJSAnnotate.getStoreAdapter().addAnnotation(documentId, pageNumber, annotation)
      .then((annotation) => {
        appendChild(svg, annotation);
      });
  }

  closeInput();
}

/**
 * Close the input
 */
function closeInput() {
  if (input) {
    input.removeEventListener('blur', handleInputBlur);
    input.removeEventListener('keyup', handleInputKeyup);
    const parent = window.document.getElementById('pageContainer1')
    parent.removeChild(input);
    input = null;
  }
}

/**
 * Set the text attributes
 *
 * @param {Number} textSize The size of the text
 * @param {String} textColor The color of the text
 */
export function setText(textSize = 12, textColor = '000000') {
  const temp = window.document.querySelector('.admin-color').childNodes[0]
  _textColor = temp.getAttribute('data-color')
  _textSize = parseInt(textSize, 10);
  _textColor = textColor;
}

/**
 * Enable text behavior
 */
export function enableText() {
  if (_enabled) {
    return;
  }

  _enabled = true;
  window.document.addEventListener('mouseup', handleDocumentMouseup);
}

/**
 * Disable text behavior
 */
export function disableText() {
  if (!_enabled) { return; }

  _enabled = false;
  window.document.removeEventListener('mouseup', handleDocumentMouseup);
}
